@@ -37,7 +37,8 @@ def screenshot(file_path: str = None, screen_region: list = None) -> List[int]:
     try:
         try:
             record_action_to_list("screenshot", param)
-            return cv2.cvtColor(np.array(pil_screenshot(file_path=file_path, screen_region=screen_region)), cv2.COLOR_RGB2BGR)
+            return cv2.cvtColor(
+                np.array(pil_screenshot(file_path=file_path, screen_region=screen_region)), cv2.COLOR_RGB2BGR)
         except AutoControlScreenException as error:
             raise AutoControlScreenException(screen_screenshot + " " + repr(error))
     except Exception as error:
